from flask import Flask, render_template, request
import os

# 创建上传图片存储路径
basedir = os.path.abspath(os.path.dirname(__file__))
file_path = os.path.join(basedir, 'img')
if not os.path.exists(file_path):
    os.makedirs(file_path)

app = Flask(__name__, static_folder=file_path, static_url_path='/show')

# 过滤非图片文件
def file_filter(filename):
    filter_ = ['png', 'jpg', 'jpeg', 'JPG', 'PNG', 'JPEG']
    return '.' in filename and filename.rsplit('.', 1)[1] in filter_

# 首页 
@app.route('/')
def index():
    return render_template('index.html')

# 图片上传接口
@app.route('/upload', methods=['POST'])
def upload():
    img = request.files['img']
    if img and file_filter(img.filename):
        img.save(file_path+'/'+img.filename)  
        return "上传成功"
    else:
        return "上传失败"
                               
# 图片查看接口
@app.route('/shows')
def shows():
    file_list = [i for i in os.listdir(file_path) if file_filter(i)]
    return render_template('shows.html', data=file_list)


if __name__ == '__main__':
    # run，指定 host 和 port
    app.run(host='0.0.0.0', port=5000, debug=True)

    
    